@@ -24,16 +24,15 @@
 
 #include <Lum/Model/Boolean.h>
 
+#include <Lum/Array.h>
 #include <Lum/Boolean.h>
 #include <Lum/Button.h>
 #include <Lum/Dialog.h>
-#include <Lum/Grid.h>
 #include <Lum/Panel.h>
 #include <Lum/PopupGroup.h>
+#include <Lum/Text.h>
 #include <Lum/Toggle.h>
 
-static GameArea::Prefs *prefs=new GameArea::Prefs();
-
 class SetSelector : public Lum::Dialog
 {
 private:
@@ -63,26 +62,35 @@ public:
 
   void PreInit()
   {
+    Lum::Array      *array;
     Lum::Button     *button;
-    Lum::Grid       *grid;
     Lum::Panel      *panel;
     Lum::PopupGroup *container;
 
     panel=new Lum::VPanel();
 
-    grid=new Lum::Grid();
-    grid->SetFlex(true,true);
-    grid->SetSize(3,3);
+    array=new Lum::Array();
+    array->SetFlex(true,true);
+    array->SetHorizontalCount(3);
 
     for (size_t i=1; i<=9; i++) {
+      Lum::Text   *text;
+
+      text=new Lum::Text();
+      text->SetFlex(true,true);
+      text->SetText(Lum::Base::NumberToWString(i),
+                    Lum::OS::display->GetFont(Lum::OS::Display::fontTypeProportional,
+                                              Lum::OS::Display::fontScaleCaption1));
+      text->SetAlignment(Lum::Text::centered);
+
       button=new Lum::Button();
       button->SetFlex(true,true);
-      button->SetText(Lum::Base::NumberToWString(i));
+      button->SetLabel(text);
       button->SetModel(models[i]);
 
-      grid->SetObject((i-1)%3,(i-1)/3,button);
+      array->Add(button);
     }
-    panel->Add(grid);
+    panel->Add(array);
 
     button=new Lum::Button();
     button->SetFlex(true,false);
@@ -151,26 +159,35 @@ public:
 
   void PreInit()
   {
-    Lum::Grid       *grid;
+    Lum::Array      *array;
     Lum::Panel      *panel;
     Lum::PopupGroup *container;
 
     panel=new Lum::VPanel();
 
-    grid=new Lum::Grid();
-    grid->SetFlex(true,true);
-    grid->SetSize(3,3);
+    array=new Lum::Array();
+    array->SetFlex(true,true);
+    array->SetHorizontalCount(3);
 
     for (size_t i=0; i<=8; i++) {
       Lum::Toggle *toggle;
+      Lum::Text   *text;
+
+      text=new Lum::Text();
+      text->SetFlex(true,true);
+      text->SetText(Lum::Base::NumberToWString(i+1),
+                    Lum::OS::display->GetFont(Lum::OS::Display::fontTypeProportional,
+                                              Lum::OS::Display::fontScaleCaption1));
+      text->SetAlignment(Lum::Text::centered);
 
       toggle=new Lum::Toggle();
+      toggle->SetFlex(true,true);
       toggle->SetModel(models[i]);
-      toggle->SetLabel(Lum::Base::NumberToWString(i+1));
+      toggle->SetLabel(text);
 
-      grid->SetObject(i%3,i/3,toggle);
+      array->Add(toggle);
     }
-    panel->Add(grid);
+    panel->Add(array);
 
     container=new Lum::PopupGroup();
     container->SetMain(panel);
@@ -219,8 +236,6 @@ GameArea::GameArea()
    focusedCell(0),
    finished(new Lum::Model::Boolean())
 {
-  SetPrefs(::prefs);
-
   SetCanFocus(true);
   RequestFocus();
 
