@@ -172,7 +172,6 @@ public:
     horiz->SetFlex(true,true);
 
     gameArea->SetFlex(true,true);
-    gameArea->RequestFocus();
     gameArea->SetModel(riddle,solution);
 
     horiz->Add(gameArea);
@@ -189,14 +188,12 @@ public:
 
     button=new Lum::Button;
     button->SetFlex(true,false);
-    button->RequestFocus();
     button->SetModel(generateAction);
     button->SetText(_(L"GENERATE",L"_Generate"));
     array->Add(button);
 
     button=new Lum::Button;
     button->SetFlex(true,false);
-    button->RequestFocus();
     button->SetModel(solveAction);
     button->SetText(_(L"SOLVE",L"_Solve"));
     array->Add(button);
@@ -217,7 +214,6 @@ public:
 
     combo=new Lum::TextEditCombo();
     combo->SetFlex(true,false);
-    combo->RequestFocus();
     combo->SetModel(minimumPoints);
     combo->SetTableModel(table);
     dynamic_cast<Lum::TextEditCombo*>(combo)->GetString()->SetAlignment(Lum::String::right);
